<?php

declare(strict_types=1);

namespace Dedi\SyliusVoucherPlugin\Checker;

use Dedi\SyliusVoucherPlugin\Model\OrderInterface as DediOrderInterface;
use Dedi\SyliusVoucherPlugin\Specification\IsOrderFullyPaidUsingVoucherSpecification;
use Sylius\Component\Core\Checker\OrderPaymentMethodSelectionRequirementCheckerInterface;
use Sylius\Component\Core\Model\OrderInterface;

/**
 * This service makes sure that the Payment method selection step should be showed
 * when an order is fully paid using vouchers
 */
class OrderPaymentMethodSelectionRequirementChecker implements OrderPaymentMethodSelectionRequirementCheckerInterface
{
    private OrderPaymentMethodSelectionRequirementCheckerInterface $baseChecker;
    private IsOrderFullyPaidUsingVoucherSpecification $isOrderFullyPaidUsingVoucherSpecification;

    public function __construct(
        OrderPaymentMethodSelectionRequirementCheckerInterface $baseChecker,
        IsOrderFullyPaidUsingVoucherSpecification $isOrderFullyPaidUsingVoucherSpecification
    ) {
        $this->baseChecker = $baseChecker;
        $this->isOrderFullyPaidUsingVoucherSpecification = $isOrderFullyPaidUsingVoucherSpecification;
    }

    public function isPaymentMethodSelectionRequired(OrderInterface $order): bool
    {
        /** @var DediOrderInterface $order */
        return $this->baseChecker->isPaymentMethodSelectionRequired($order) ||
            $this->isOrderFullyPaidUsingVoucherSpecification->__invoke($order)
        ;
    }
}
