<?php

declare(strict_types=1);

namespace Tests\Dedi\SyliusVoucherPlugin\Behat\Context\Setup;

use Behat\Behat\Context\Context;
use Dedi\SyliusVoucherPlugin\Factory\VoucherFactoryInterface;
use Dedi\SyliusVoucherPlugin\Repository\VoucherRepositoryInterface;
use Sylius\Component\Channel\Repository\ChannelRepositoryInterface;
use Sylius\Component\Core\Repository\CustomerRepositoryInterface;

class VoucherContext implements Context
{
    private ChannelRepositoryInterface $channelRepository;
    private CustomerRepositoryInterface $customerRepository;
    private VoucherFactoryInterface $voucherFactory;
    private VoucherRepositoryInterface $voucherRepository;

    public function __construct(
        ChannelRepositoryInterface $channelRepository,
        CustomerRepositoryInterface $customerRepository,
        VoucherFactoryInterface $voucherFactory,
        VoucherRepositoryInterface $voucherRepository
    ) {
        $this->channelRepository = $channelRepository;
        $this->customerRepository = $customerRepository;
        $this->voucherFactory = $voucherFactory;
        $this->voucherRepository = $voucherRepository;
    }

    /**
     * @Given the customer :email has a voucher with the following amount :amount in the channel :channelCode
     * @Given the customer :email has a voucher with the following amount :amount and code :code in the channel :channelCode
     */
    public function theCustomerHasAVoucherWithTheFollowingAmount($email, $amount, $channelCode, $code = null)
    {
        $customer = $this->customerRepository->findOneBy(['email' => $email]);

        $voucher = $this->voucherFactory->createNew();
        if ($code != null) {
            $voucher->setCode($code);
        }
        $voucher->setAmount(((int) $amount) * 100);
        $voucher->setInitialAmount(((int) $amount) * 100);
        $voucher->setCurrencyCode('USD');
        $voucher->setChannel($this->channelRepository->findOneByCode($channelCode));
        $voucher->setCustomer($customer);

        $this->voucherRepository->add($voucher);
    }
}
