<?php

declare(strict_types=1);

namespace Tests\Dedi\SyliusVoucherPlugin\Behat\Context\Ui\Admin;

use Behat\Behat\Context\Context;
use Tests\Dedi\SyliusVoucherPlugin\Behat\Page\Admin\CreateVoucherPageInterface;
use Tests\Dedi\SyliusVoucherPlugin\Behat\Page\Admin\IndexVoucherPageInterface;
use Webmozart\Assert\Assert;

class ManagingVoucherContext implements Context
{
    private IndexVoucherPageInterface $indexVoucherPage;
    private CreateVoucherPageInterface $createVoucherPage;

    public function __construct(
        IndexVoucherPageInterface $indexVoucherPage,
        CreateVoucherPageInterface $createVoucherPage
    ) {
        $this->indexVoucherPage = $indexVoucherPage;
        $this->createVoucherPage = $createVoucherPage;
    }

    /**
     * @Given I want to create a new voucher for the :channelIdentifier channel
     */
    public function iWantToCreateANewVoucherForTheChannel($channelIdentifier)
    {
        $this->createVoucherPage->open([
            'channelCode' => $channelIdentifier,
        ]);
    }

    /**
     * @When I choose :email as the customer
     */
    public function iChooseEmailAsTheCustomer($email)
    {
        $this->createVoucherPage->setCustomerEmail($email);
    }

    /**
     * @When I set the amount to :amount
     */
    public function iSetTheAmountToAmount($amount)
    {
        $this->createVoucherPage->setAmount($amount);
    }

    /**
     * @When I add it
     */
    public function iAddIt()
    {
        $this->createVoucherPage->create();
    }

    /**
     * @Then I want to see the list of vouchers
     */
    public function iWantToSeeTheListOfVouchers()
    {
        $this->indexVoucherPage->open();
    }

    /**
     * @Then I should see a voucher for :customer with the following amount :amount
     */
    public function iShouldSeeAVoucher($customer, $amount)
    {
        Assert::true($this->indexVoucherPage->isSingleResourceOnPage([
            'customer' => $customer,
            'amount' => $amount,
        ]));
    }
}
