<?php

declare(strict_types=1);

namespace Tests\Dedi\SyliusVoucherPlugin\Behat\Context\Ui\Shop;

use Behat\Behat\Context\Context;
use Dedi\SyliusVoucherPlugin\Repository\VoucherRepositoryInterface;
use Tests\Dedi\SyliusVoucherPlugin\Behat\Page\Shop\PaymentPageInterface;
use Webmozart\Assert\Assert;

class UsingVoucherContext implements Context
{
    private PaymentPageInterface $paymentPage;
    private VoucherRepositoryInterface $voucherRepository;

    public function __construct(
        PaymentPageInterface $paymentPage,
        VoucherRepositoryInterface $voucherRepository
    ) {
        $this->paymentPage = $paymentPage;
        $this->voucherRepository = $voucherRepository;
    }

    /**
     * @When I use my voucher with the code :code
     */
    public function iUseMyVoucher($code)
    {
        $this->paymentPage->open();

        $voucher = $this->voucherRepository->findOneByCode($code);
        Assert::notNull($voucher);

        $this->paymentPage->applyVoucherWithId($voucher->getId());
    }

    /**
     * @Then The vouchers total should be equal to :total
     */
    public function theVouchersTotalShouldBeEqualTo($total)
    {
        Assert::true($this->paymentPage->isVoucherTotalEqualTo($total));
    }

    /**
     * @Then The order total should be equal to :total
     */
    public function theOrderTotalShouldBeEqualTo($total)
    {
        Assert::true($this->paymentPage->isOrderTotalEqualTo($total));
    }

    /**
     * @When I remove my voucher with the code :code
     */
    public function iRemoveMyVoucherWithCode($code)
    {
        $this->paymentPage->removeVoucherWithCode($code);
    }

    /**
     * @Then The vouchers total should not be displayed
     */
    public function theVouchersTotalShouldNotBeDisplayed()
    {
        Assert::false($this->paymentPage->isVoucherTotalDisplayed());
    }
}
